mailr4547 - /1.3/test_suite/unit_tests/_prompt/test_state.py


Others Months | Index by Date | Thread Index
>>   [Date Prev] [Date Next] [Thread Prev] [Thread Next]

Header


Content

Posted by edward on January 09, 2008 - 14:30:
Author: bugman
Date: Wed Jan  9 14:30:40 2008
New Revision: 4547

URL: http://svn.gna.org/viewcvs/relax?rev=4547&view=rev
Log:
Updated the force arg unit test of the state.save() user function.

The arg is now a boolean.


Modified:
    1.3/test_suite/unit_tests/_prompt/test_state.py

Modified: 1.3/test_suite/unit_tests/_prompt/test_state.py
URL: 
http://svn.gna.org/viewcvs/relax/1.3/test_suite/unit_tests/_prompt/test_state.py?rev=4547&r1=4546&r2=4547&view=diff
==============================================================================
--- 1.3/test_suite/unit_tests/_prompt/test_state.py (original)
+++ 1.3/test_suite/unit_tests/_prompt/test_state.py Wed Jan  9 14:30:40 2008
@@ -26,7 +26,7 @@
 # relax module imports.
 from test_suite.unit_tests.state_testing_base import State_base_class
 from prompt.state import State
-from relax_errors import RelaxBinError, RelaxIntError, RelaxNoneStrError, 
RelaxStrFileError
+from relax_errors import RelaxBoolError, RelaxIntError, RelaxNoneStrError, 
RelaxStrFileError
 
 # Unit test imports.
 from data_types import DATA_TYPES
@@ -101,12 +101,12 @@
 
         # Loop over the data types.
         for data in DATA_TYPES:
-            # Catch the bin arguments, and skip them.
-            if data[0] == 'bin':
+            # Catch the bool arguments, and skip them.
+            if data[0] == 'bool':
                 continue
 
             # The argument test.
-            self.assertRaises(RelaxBinError, self.state.save_state, 
state='a', force=data[1])
+            self.assertRaises(RelaxBoolError, self.state.save_state, 
state='a', force=data[1])
 
 
     def test_save_argfail_compress_type(self):




Related Messages


Powered by MHonArc, Updated Wed Jan 09 14:40:12 2008